- [DATA SOURCE]
    - Original paper:
        - https://doi.org/10.1029/2022GL099235
    - Download links (both are from the "Data Availability Statement" of the paper above; both contain the same data but in different formats):
        1. Single XLSX file: https://data.mendeley.com/datasets/3jd9whd78m/1
            - We choose this one for convenience
        2. Separated into multiple text files: https://repository.lsu.edu/geo_psl/1/
    - Hash of first option (XLSX):
        - sha256  : 06f7b8cfc89a803c714a7dd69beba0d65ba9f26ccf8eb5ddc276e280c4e5b917
